@@ -73,7 +73,7 @@ pub(crate) mod NodeList {
 }
 
 #[allow(non_snake_case)]
-#[allow(clippy::box_vec)]
+#[allow(clippy::box_collection)]
 pub(crate) mod BoxedNodeList {
     use super::{Node, ParseValue};
 
@@ -486,7 +486,7 @@ pub(crate) struct MatchPatternWithTrailingComma {
     pub(crate) trailing_comma: Option<PoolValue<Token>>,
 }
 impl MatchPatternWithTrailingComma {
-    pub(crate) fn from(value: ParseValue) -> MatchPatternWithTrailingComma {
+    pub(crate) fn from(value: ParseValue) -> Self {
         match value {
             ParseValue::MatchPatternWithTrailingComma(value) => *value,
             other => unreachable!("expected MatchPatternWithTrailingComma, got {:?}", other),
@@ -494,7 +494,21 @@ impl MatchPatternWithTrailingComma {
     }
 }
 
-#[allow(clippy::box_vec)]
+#[derive(Debug, Clone)]
+pub(crate) struct NoKwRest {
+    pub(crate) kwrest_mark: PoolValue<Token>,
+    pub(crate) k_nil: PoolValue<Token>,
+}
+impl NoKwRest {
+    pub(crate) fn from(value: ParseValue) -> Self {
+        match value {
+            ParseValue::NoKwRest(value) => *value,
+            other => unreachable!("expected NoKwRest, got {:?}", other),
+        }
+    }
+}
+
+#[allow(clippy::box_collection)]
 #[derive(Clone, Debug)]
 pub(crate) enum ParseValue {
     Stolen,
@@ -584,6 +598,9 @@ pub(crate) enum ParseValue {
 
     /* For pattern matching patterns with trailing comma */
     MatchPatternWithTrailingComma(Box<MatchPatternWithTrailingComma>),
+
+    /* For p_kwnorest and f_no_kwarg rules */
+    NoKwRest(Box<NoKwRest>),
 }
 
 impl ParseValue {
@@ -672,6 +689,9 @@ impl ParseValue {
     ) -> Self {
         Self::MatchPatternWithTrailingComma(Box::new(value))
     }
+    pub(crate) fn new_no_kw_rest(value: NoKwRest) -> Self {
+        Self::NoKwRest(Box::new(value))
+    }
 }
 
 impl Default for ParseValue {
